@@ -10,11 +10,20 @@ __author__ = "Duncan Macleod <duncan.macleod@ligo.org>"
 import os
 from pathlib import Path
 
-from .error import IgwnAuthError
+from jwt import InvalidTokenError
 from scitokens import (
     Enforcer,
     SciToken,
 )
+from scitokens.utils.errors import SciTokensException
+
+from .error import IgwnAuthError
+
+TOKEN_ERROR = (
+    InvalidTokenError,
+    SciTokensException,
+)
+
 
 WINDOWS = os.name == "nt"
 
@@ -24,13 +33,25 @@ WINDOWS = os.name == "nt"
 def is_valid_token(token, audience, scope, timeleft=600):
     enforcer = Enforcer(token["iss"], audience=audience)
 
+    # add validator for timeleft
     def _validate_timeleft(value):
         exp = float(value)
         return exp >= enforcer._now + timeleft
 
     enforcer.add_validator("exp", _validate_timeleft)
-    scheme, path = scope.split(":", 1)
-    return enforcer.test(token, scheme, path)
+
+    # if scope wasn't given, borrow one from the token to pass validation
+    if scope is None:
+        scope = token["scope"].split(" ", 1)[0]
+    # parse scope as scheme:path
+    try:
+        authz, path = scope.split(":", 1)
+    except ValueError:
+        authz = scope
+        path = None
+
+    # test
+    return enforcer.test(token, authz, path=path)
 
 
 # -- I/O --------------------
@@ -132,13 +153,17 @@ def find_token(audience, scope, timeleft=600, skip_errors=False, **kwargs):
     scitokens.SciToken.deserialize
         for details of the deserialisation, and any valid keyword arguments
     """
+    # preserve error from parsing tokens
+    error = None
+
     # iterate over all of the tokens we can find for this audience
     for token in _find_tokens(audience=audience, **kwargs):
         # parsing a token yielded an exception, handle it here:
         if isinstance(token, Exception):
+            error = error or token  # record (first) error for later
             if skip_errors:
-                continue
-            raise token
+                continue  # move on
+            raise IgwnAuthError(str(error)) from error  # stop here and raise
 
         # if this token is valid, stop here and return it
         if is_valid_token(token, audience, scope, timeleft):
@@ -149,7 +174,7 @@ def find_token(audience, scope, timeleft=600, skip_errors=False, **kwargs):
         "could not find a valid SciToken, "
         "please verify the audience and scope, "
         "or generate a new token and try again",
-    )
+    ) from error
 
 
 def _find_tokens(**deserialize_kwargs):
@@ -159,12 +184,10 @@ def _find_tokens(**deserialize_kwargs):
     attempting to parse a token that was actually found, so that
     they can be handled by the caller.
     """
-    from scitokens.utils.errors import SciTokensException
-
     def _token_or_exception(func, *args, **kwargs):
         try:
             return func(*args, **kwargs)
-        except SciTokensException as exc:
+        except TOKEN_ERROR as exc:
             return exc
 
     # read token directly from 'SCITOKEN{_FILE}' variable
