@@ -12,7 +12,7 @@ import time
 from unittest import mock
 
 from scitokens import SciToken
-from scitokens.utils.errors import NonHTTPSIssuer
+from scitokens.scitokens import InvalidPathError
 
 import pytest
 
@@ -26,6 +26,10 @@ READ_SCOPE = "read:{}".format(_SCOPE_PATH)
 WRITE_SCOPE = "write:{}".format(_SCOPE_PATH)
 
 
+def _os_error(*args, **kwargs):
+    raise OSError
+
+
 def _create_token(
     key=None,
     iss=ISSUER,
@@ -115,13 +119,19 @@ def _assert_claims_equal(a, b):
 # -- tests --------------------------------------
 
 @pytest.mark.parametrize(("scope", "validity"), (
-    (READ_SCOPE, True),
-    (WRITE_SCOPE, False),
+    (READ_SCOPE, True),  # read scope matches token
+    (WRITE_SCOPE, False),  # write scope doesn't
+    (None, True),  # accept any scope
 ))
 def test_is_valid_token(rtoken, scope, validity):
     assert igwn_scitokens.is_valid_token(rtoken, AUDIENCE, scope) is validity
 
 
+def test_is_valid_token_invalid_path(rtoken):
+    with pytest.raises(InvalidPathError):
+        igwn_scitokens.is_valid_token(rtoken, AUDIENCE, "read")
+
+
 def test_load_token_file(rtoken_path, rtoken, public_pem):
     assert_tokens_equal(
         igwn_scitokens.load_token_file(
@@ -181,6 +191,8 @@ def test_find_token_env_scitoken_file(
 
 
 @mock.patch.dict("os.environ")
+# make sure a real token doesn't get in the way
+@mock.patch("igwn_auth_utils.scitokens.SciToken.discover", _os_error)
 def test_find_token_condor_creds(
     rtoken,
     wtoken,
@@ -204,6 +216,8 @@ def test_find_token_condor_creds(
 
 
 @mock.patch.dict("os.environ")
+# make sure a real token doesn't get in the way
+@mock.patch("igwn_auth_utils.scitokens.SciToken.discover", _os_error)
 def test_find_token_error(rtoken, public_pem):
     # token with the wrong claims
     os.environ["SCITOKEN"] = rtoken.serialize().decode("utf-8")
@@ -221,11 +235,11 @@ def test_find_token_error(rtoken, public_pem):
 
 
 @mock.patch.dict("os.environ")
-@pytest.mark.parametrize(("skip_errors", "error_type", "message"), (
-    (False, NonHTTPSIssuer, "Issuer is not over HTTPS"),
-    (True, IgwnAuthError, "could not find a valid SciToken"),
+@pytest.mark.parametrize(("skip_errors", "message"), (
+    (False, "Issuer is not over HTTPS"),
+    (True, "could not find a valid SciToken"),
 ))
-def test_find_token_skip_errors(rtoken, skip_errors, error_type, message):
+def test_find_token_skip_errors(rtoken, skip_errors, message):
     """Check that the ``skip_errors`` keyword for `find_token()` works
     """
     # configure a valid token (wrong claims) **HOWEVER**
@@ -235,7 +249,7 @@ def test_find_token_skip_errors(rtoken, skip_errors, error_type, message):
     os.environ["SCITOKEN"] = rtoken.serialize().decode("utf-8")
 
     # check that we get the normal error
-    with pytest.raises(error_type) as exc:
+    with pytest.raises(IgwnAuthError) as exc:
         igwn_scitokens.find_token(
             AUDIENCE,
             READ_SCOPE,
